/*
  gmap.h
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __GMAP_H__
#define __GMAP_H__

#include <qwidget.h>
#include <qvbox.h>
#include <qmenubar.h>
#include <qlabel.h>
#include <qpixmapcache.h>
#include <qpoint.h>
#include <qarray.h>
#include <qcache.h>

#include "map.h"
#include "qgmap.h"
#include "qgconf.h"
#include "scale.h"
#include "marker.h"

class GMap : public QWidget
{
	Q_OBJECT
  public:
	GMap( QWidget *parent =0, const char *name = 0, WFlags fl = 0);
	void updateCenter(bool force);

	void dispInfo(QString str);
	Pos getPosition(int i);

  private:
	void paintEvent( QPaintEvent *e );
	void wheelEvent( QWheelEvent *e );
	void mouseMoveEvent( QMouseEvent *e );
	void mousePressEvent( QMouseEvent *e );
	void mouseReleaseEvent( QMouseEvent *e );

	void keyPressEvent ( QKeyEvent * e );
	void keyReleaseEvent ( QKeyEvent * e );

	void timerEvent( QTimerEvent *e );

	void showEvent( QShowEvent *e );

	int x_num;
	int y_num;

	int load_top;
	int load_left;

	Pos center;
	QPixmapCache cache;
	QCache<QImage> img_cache;

	QArray<Map *> pix;

	QPixmap scr;

	bool is_map_click;
	bool is_scale_click;
	QPoint click_pos;

	QGConf conf;
	QString map_path;

	QPixmap menu_pic;

	QPopupMenu popup_menu;

	void loadMap(Pos loadpos);

	void scroll(int x, int y);
	void zoomup(int z);

	int scale_size;
	int scale_mul;
	void calcScale();
	void drawScale(QPixmap *scr);

	Scale *scale;

	void jumpLocation();

	void savePosition(int i);
	void loadPosition(int i);

	QLabel info_label;
	int info_timer_id;

	Marker marker;

	bool is_help;
	QLabel help_label;
	void dispHelp();
	void hideHelp();

  public slots:

	void menu_activated(int id);
};

#endif // __GMAP_H__
