/*
  marker.h
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __MARKER_H__
#define __MARKER_H__

#include "qgmap.h"
#include <qpixmap.h>
#include "pos.h"

#define MARKER_SIZE 16
#define ARROW_SIZE 8

#define M_TOP 50
#define M_BOTTOM 30
#define M_LEFT 20
#define M_RIGHT 50

#define M_ARROW_LEN 12
#define M_ARROW_LEN45 9

#define MARKER_FILE APP_PATH "/marker.png"

#define IS_MARKER_BIT(a) (marker_bit&(1<<(a)))
#define MARKER_TOGGLE(a) (marker_bit ^= 1<<(a))

class Marker {
  public:
	Marker(QWidget *parent, const Pos *center);
	~Marker();

	void paint(QPixmap *scr);
	void drawMarker(QPixmap *scr, Pos pos, int index);

	bool timerEvent( QTimerEvent *e );
	bool keyPressEvent ( QKeyEvent * e );

  protected:
	QWidget *parent;
	const Pos *center;

	QPixmap base;
	QPixmap arrow[9];

	void drawBase(QPixmap *scr, int cx, int cy, int index);

	bool isClip(QPixmap *scr, int sx ,int sy);
	void drawClipMarker(QPixmap *scr, int sx, int sy, int index);

	void getMarkerpos(int dx, int dy, int max_x, int max_y,
					  int *mx, int *my, int *ax, int *ay);

	bool marker_on;
	int marker_bit;

	bool key_marker_mode;

	int marker_timer_id;

	void dispMarkerInfo();
};

#endif // __MARKER_H__
