/*
  scale.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include <qwidget.h>
#include <qpixmap.h>
#include <qstring.h>
#include <qpainter.h>
#include "qgmap.h"
#include "scale.h"
#include "pos.h"

Scale::Scale(QPixmap *pix, Pos *pos)
	:slider_base(8,26), nob_center(9,5) , slider_mul(0,8)
{
	scr = pix;
	center = pos;

	is_button = FALSE;

	loadImage();
}

void Scale::loadImage()
{
	slider.load(SLIDERIMG_FILE);
	nob.load(NOBIMG_FILE);
}

bool Scale::paintEvent(QPaintEvent *e)
{
	QPainter p(scr);

	QPoint pos = topLeft();

	p.drawPixmap( pos, slider );

	pos += slider_base - nob_center;
	pos += slider_mul * (center->getZoom());
	p.drawPixmap( pos, nob );

	p.end();
	return TRUE;
}

bool Scale::pressEvent(QMouseEvent *e)
{
	int z;
	int y = (e->pos() - topLeft()).y();

	if(y <= 16){
		center->zoomup(-1);
		is_button = TRUE;
		return TRUE;
	}
	if(y >= 188){
		center->zoomup(1);
		is_button = TRUE;
		return TRUE;
	}

	z = y - slider_base.y() + slider_mul.y()/2;
	z /= slider_mul.y();
	z = (z < 0)?0:z;
	z = (z > 19)?19:z;

	if(center->getZoom() != z){
		center->zoomup(z-center->getZoom());
		return TRUE;
	}
	return FALSE;
}

bool Scale::releaseEvent(QMouseEvent *e)
{
	is_button = FALSE;
	return FALSE;
}

bool Scale::moveEvent(QMouseEvent *e)
{
	if(is_button)
		return FALSE;
	return pressEvent(e);
}

QPoint Scale::topLeft()
{
	QPoint topleft(scr->width()-slider.width()-20, (scr->height()-slider.height())/2);
	return topleft;
}

QRect Scale::rect()
{
	QPoint topleft = topLeft();
	QRect r(topleft, slider.size());
	return r;
}
